@@ -29,30 +29,18 @@ class FreeBSD extends BSDCommon
     /**
      * define the regexp for log parser
      */
-    public function __construct()
+    public function __construct($blockname = false)
     {
-        parent::__construct();
+        parent::__construct($blockname);
         $this->setCPURegExp1("/CPU: (.*) \((.*)-MHz (.*)\)/");
         $this->setCPURegExp2("/(.*) ([0-9]+) ([0-9]+) ([0-9]+) ([0-9]+)/");
         $this->setSCSIRegExp1("/^(.*): <(.*)> .*SCSI.*device/");
         $this->setSCSIRegExp2("/^(da[0-9]+): (.*)MB /");
+        $this->setSCSIRegExp3("/^(da[0-9]+|cd[0-9]+): Serial Number (.*)/");
         $this->setPCIRegExp1("/(.*): <(.*)>(.*) pci[0-9]+$/");
         $this->setPCIRegExp2("/(.*): <(.*)>.* at [.0-9]+ irq/");
     }
 
-    /**
-     * UpTime
-     * time the system is running
-     *
-     * @return void
-     */
-    private function _uptime()
-    {
-        $s = preg_split('/ /', $this->grabkey('kern.boottime'));
-        $a = preg_replace('/,/', '', $s[3]);
-        $this->sys->setUptime(time() - $a);
-    }
-
     /**
      * get network information
      *
@@ -132,9 +120,19 @@ class FreeBSD extends BSDCommon
      */
     private function _distroicon()
     {
-        if (extension_loaded('pfSense') && CommonFunctions::rfts('/etc/version', $version, 1, 4096, false) && (trim($version) != '')) { // pfSense detection
-            $this->sys->setDistribution('pfSense '. trim($version));
-            $this->sys->setDistributionIcon('pfSense.png');
+        if (CommonFunctions::rfts('/etc/version', $version, 1, 4096, false) && (($version=trim($version)) != '')) {
+            if (extension_loaded('pfSense')) { // pfSense detection
+                $this->sys->setDistribution('pfSense '. $version);
+                $this->sys->setDistributionIcon('pfSense.png');
+            } elseif (preg_match('/^FreeNAS/i', $version)) { // FreeNAS detection
+                $this->sys->setDistribution($version);
+                $this->sys->setDistributionIcon('FreeNAS.png');
+            } elseif (preg_match('/^TrueNAS/i', $version)) { // TrueNAS detection
+                $this->sys->setDistribution($version);
+                $this->sys->setDistributionIcon('TrueNAS.png');
+            } else {
+                $this->sys->setDistributionIcon('FreeBSD.png');
+            }
         } else {
             $this->sys->setDistributionIcon('FreeBSD.png');
         }
@@ -187,21 +185,20 @@ class FreeBSD extends BSDCommon
      *
      * @see BSDCommon::build()
      *
-     * @return Void
+     * @return void
      */
     public function build()
     {
         parent::build();
-        if (!defined('PSI_ONLY') || PSI_ONLY==='vitals') {
+        if (!$this->blockname || $this->blockname==='vitals') {
             $this->_distroicon();
-            $this->_uptime();
             $this->_processes();
         }
-        if (!defined('PSI_ONLY') || PSI_ONLY==='network') {
-            $this->_network();
-        }
-        if (!defined('PSI_ONLY') || PSI_ONLY==='memory') {
+        if (!$this->blockname || $this->blockname==='memory') {
             $this->_memoryadditional();
         }
+        if (!$this->blockname || $this->blockname==='network') {
+            $this->_network();
+        }
     }
 }
