@@ -28,70 +28,70 @@ class System
     /**
      * name of the host where phpSysInfo runs
      *
-     * @var String
+     * @var string
      */
     private $_hostname = "localhost";
 
     /**
      * ip of the host where phpSysInfo runs
      *
-     * @var String
+     * @var string
      */
     private $_ip = "127.0.0.1";
 
     /**
-     * detailed Information about the kernel
+     * detailed information about the kernel
      *
-     * @var String
+     * @var string
      */
     private $_kernel = "Unknown";
 
     /**
      * name of the distribution
      *
-     * @var String
+     * @var string
      */
     private $_distribution = "Unknown";
 
     /**
      * icon of the distribution (must be available in phpSysInfo)
      *
-     * @var String
+     * @var string
      */
     private $_distributionIcon = "unknown.png";
 
     /**
      * detailed Information about the machine name
      *
-     * @var String
+     * @var string
      */
     private $_machine = "";
 
     /**
      * time in sec how long the system is running
      *
-     * @var Integer
+     * @var int
      */
     private $_uptime = 0;
 
     /**
      * count of users that are currently logged in
      *
-     * @var Integer
+     * @var int
      */
     private $_users = 0;
 
     /**
      * load of the system
      *
-     * @var String
+     * @var string
      */
     private $_load = "";
 
     /**
      * load of the system in percent (all cpus, if more than one)
      *
-     * @var Integer
+     * @var int
      */
     private $_loadPercent = null;
 
@@ -167,6 +167,24 @@ class System
      */
     private $_i2cDevices = array();
 
+    /**
+     * array with NVMe devices
+     *
+     * @see HWDevice
+     *
+     * @var array
+     */
+    private $_nvmeDevices = array();
+
+    /**
+     * array with Mem devices
+     *
+     * @see HWDevice
+     *
+     * @var array
+     */
+    private $_memDevices = array();
+
     /**
      * array with disk devices
      *
@@ -179,42 +197,42 @@ class System
     /**
      * free memory in bytes
      *
-     * @var Integer
+     * @var int
      */
     private $_memFree = 0;
 
     /**
      * total memory in bytes
      *
-     * @var Integer
+     * @var int
      */
     private $_memTotal = 0;
 
     /**
      * used memory in bytes
      *
-     * @var Integer
+     * @var int
      */
     private $_memUsed = 0;
 
     /**
      * used memory by applications in bytes
      *
-     * @var Integer
+     * @var int
      */
     private $_memApplication = null;
 
     /**
      * used memory for buffers in bytes
      *
-     * @var Integer
+     * @var int
      */
     private $_memBuffer = null;
 
     /**
      * used memory for cache in bytes
      *
-     * @var Integer
+     * @var int
      */
     private $_memCache = null;
 
@@ -234,6 +252,20 @@ class System
      */
     private $_processes = array();
 
+    /**
+     *  array with Virtualizer information
+     *
+     * @var array
+     */
+    private $_virtualizer = array();
+
+    /**
+     * operating system type
+     *
+     * @var string
+     */
+    private $_OS = "";
+
     /**
      * remove duplicate Entries and Count
      *
@@ -273,7 +305,7 @@ class System
      * @see System::_memUsed
      * @see System::_memTotal
      *
-     * @return Integer
+     * @return int
      */
     public function getMemPercentUsed()
     {
@@ -290,7 +322,7 @@ class System
      * @see System::_memApplication
      * @see System::_memTotal
      *
-     * @return Integer
+     * @return int
      */
     public function getMemPercentApplication()
     {
@@ -311,7 +343,7 @@ class System
      * @see System::_memCache
      * @see System::_memTotal
      *
-     * @return Integer
+     * @return int
      */
     public function getMemPercentCache()
     {
@@ -336,7 +368,7 @@ class System
      * @see System::_memBuffer
      * @see System::_memTotal
      *
-     * @return Integer
+     * @return int
      */
     public function getMemPercentBuffer()
     {
@@ -367,7 +399,7 @@ class System
      * @see System::_swapDevices
      * @see DiskDevice::getFree()
      *
-     * @return Integer
+     * @return int
      */
     public function getSwapFree()
     {
@@ -389,7 +421,7 @@ class System
      * @see System::_swapDevices
      * @see DiskDevice::getTotal()
      *
-     * @return Integer
+     * @return int
      */
     public function getSwapTotal()
     {
@@ -411,7 +443,7 @@ class System
      * @see System::_swapDevices
      * @see DiskDevice::getUsed()
      *
-     * @return Integer
+     * @return int
      */
     public function getSwapUsed()
     {
@@ -433,7 +465,7 @@ class System
      * @see System::getSwapUsed()
      * @see System::getSwapTotal()
      *
-     * @return Integer
+     * @return int
      */
     public function getSwapPercentUsed()
     {
@@ -467,7 +499,7 @@ class System
      *
      * @see System::$_distribution
      *
-     * @return Void
+     * @return void
      */
     public function setDistribution($distribution)
     {
@@ -493,7 +525,7 @@ class System
      *
      * @see System::$_distributionIcon
      *
-     * @return Void
+     * @return void
      */
     public function setDistributionIcon($distributionIcon)
     {
@@ -519,7 +551,7 @@ class System
      *
      * @see System::$_hostname
      *
-     * @return Void
+     * @return void
      */
     public function setHostname($hostname)
     {
@@ -545,7 +577,7 @@ class System
      *
      * @see System::$_ip
      *
-     * @return Void
+     * @return void
      */
     public function setIp($ip)
     {
@@ -571,7 +603,7 @@ class System
      *
      * @see System::$_kernel
      *
-     * @return Void
+     * @return void
      */
     public function setKernel($kernel)
     {
@@ -597,7 +629,7 @@ class System
      *
      * @see System::$_load
      *
-     * @return Void
+     * @return void
      */
     public function setLoad($load)
     {
@@ -609,7 +641,7 @@ class System
      *
      * @see System::$_loadPercent
      *
-     * @return Integer
+     * @return int
      */
     public function getLoadPercent()
     {
@@ -619,11 +651,11 @@ class System
     /**
      * Sets $_loadPercent.
      *
-     * @param Integer $loadPercent load percent
+     * @param int $loadPercent load percent
      *
      * @see System::$_loadPercent
      *
-     * @return Void
+     * @return void
      */
     public function setLoadPercent($loadPercent)
     {
@@ -649,7 +681,7 @@ class System
      *
      * @see System::$_machine
      *
-     * @return Void
+     * @return void
      */
     public function setMachine($machine)
     {
@@ -661,7 +693,7 @@ class System
      *
      * @see System::$_uptime
      *
-     * @return Integer
+     * @return int
      */
     public function getUptime()
     {
@@ -675,7 +707,7 @@ class System
      *
      * @see System::$_uptime
      *
-     * @return Void
+     * @return void
      */
     public function setUptime($uptime)
     {
@@ -687,7 +719,7 @@ class System
      *
      * @see System::$_users
      *
-     * @return Integer
+     * @return int
      */
     public function getUsers()
     {
@@ -697,11 +729,11 @@ class System
     /**
      * Sets $_users.
      *
-     * @param Integer $users user count
+     * @param int $users user count
      *
      * @see System::$_users
      *
-     * @return Void
+     * @return void
      */
     public function setUsers($users)
     {
@@ -728,7 +760,7 @@ class System
      * @see System::$_cpus
      * @see CpuDevice
      *
-     * @return Void
+     * @return void
      */
     public function setCpus($cpus)
     {
@@ -744,6 +776,10 @@ class System
      */
     public function getNetDevices()
     {
+        if (defined('PSI_SORT_NETWORK_INTERFACES_LIST') && PSI_SORT_NETWORK_INTERFACES_LIST) {
+            usort($this->_netDevices, array('CommonFunctions', 'name_natural_compare'));
+        }
+
         return $this->_netDevices;
     }
 
@@ -755,7 +791,7 @@ class System
      * @see System::$_netDevices
      * @see NetDevice
      *
-     * @return Void
+     * @return void
      */
     public function setNetDevices($netDevices)
     {
@@ -782,7 +818,7 @@ class System
      * @see System::$_pciDevices
      * @see HWDevice
      *
-     * @return Void
+     * @return void
      */
     public function setPciDevices($pciDevices)
     {
@@ -809,7 +845,7 @@ class System
      * @see System::$_ideDevices
      * @see HWDevice
      *
-     * @return Void
+     * @return void
      */
     public function setIdeDevices($ideDevices)
     {
@@ -836,7 +872,7 @@ class System
      * @see System::$_scsiDevices
      * @see HWDevice
      *
-     * @return Void
+     * @return void
      */
     public function setScsiDevices($scsiDevices)
     {
@@ -863,7 +899,7 @@ class System
      * @see System::$_usbDevices
      * @see HWDevice
      *
-     * @return Void
+     * @return void
      */
     public function setUsbDevices($usbDevices)
     {
@@ -890,7 +926,7 @@ class System
      * @see System::$_tbDevices
      * @see HWDevice
      *
-     * @return Void
+     * @return void
      */
     public function setTbDevices($tbDevices)
     {
@@ -917,13 +953,67 @@ class System
      * @see System::$_i2cDevices
      * @see HWDevice
      *
-     * @return Void
+     * @return void
      */
     public function setI2cDevices($i2cDevices)
     {
         array_push($this->_i2cDevices, $i2cDevices);
     }
 
+    /**
+     * Returns $_nvmeDevices.
+     *
+     * @see System::$_nvmeDevices
+     *
+     * @return array
+     */
+    public function getNvmeDevices()
+    {
+        return $this->_nvmeDevices;
+    }
+
+    /**
+     * Sets $_nvmeDevices.
+     *
+     * @param HWDevice $nvmeDevices NVMe device
+     *
+     * @see System::$_nvmeDevices
+     * @see HWDevice
+     *
+     * @return void
+     */
+    public function setNvmeDevices($nvmeDevices)
+    {
+        array_push($this->_nvmeDevices, $nvmeDevices);
+    }
+
+    /**
+     * Returns $_memDevices.
+     *
+     * @see System::$_memDevices
+     *
+     * @return array
+     */
+    public function getMemDevices()
+    {
+        return $this->_memDevices;
+    }
+
+    /**
+     * Sets $_memDevices.
+     *
+     * @param HWDevice $memDevices mem device
+     *
+     * @see System::$_memDevices
+     * @see HWDevice
+     *
+     * @return void
+     */
+    public function setMemDevices($memDevices)
+    {
+        array_push($this->_memDevices, $memDevices);
+    }
+
     /**
      * Returns $_diskDevices.
      *
@@ -956,7 +1046,7 @@ class System
      *
      * @see System::$_memApplication
      *
-     * @return Integer
+     * @return int
      */
     public function getMemApplication()
     {
@@ -966,11 +1056,11 @@ class System
     /**
      * Sets $_memApplication.
      *
-     * @param Integer $memApplication application memory
+     * @param int $memApplication application memory
      *
      * @see System::$_memApplication
      *
-     * @return Void
+     * @return void
      */
     public function setMemApplication($memApplication)
     {
@@ -982,7 +1072,7 @@ class System
      *
      * @see System::$_memBuffer
      *
-     * @return Integer
+     * @return int
      */
     public function getMemBuffer()
     {
@@ -992,11 +1082,11 @@ class System
     /**
      * Sets $_memBuffer.
      *
-     * @param Integer $memBuffer buffer memory
+     * @param int $memBuffer buffer memory
      *
      * @see System::$_memBuffer
      *
-     * @return Void
+     * @return void
      */
     public function setMemBuffer($memBuffer)
     {
@@ -1008,7 +1098,7 @@ class System
      *
      * @see System::$_memCache
      *
-     * @return Integer
+     * @return int
      */
     public function getMemCache()
     {
@@ -1018,11 +1108,11 @@ class System
     /**
      * Sets $_memCache.
      *
-     * @param Integer $memCache cache memory
+     * @param int $memCache cache memory
      *
      * @see System::$_memCache
      *
-     * @return Void
+     * @return void
      */
     public function setMemCache($memCache)
     {
@@ -1034,7 +1124,7 @@ class System
      *
      * @see System::$_memFree
      *
-     * @return Integer
+     * @return int
      */
     public function getMemFree()
     {
@@ -1044,11 +1134,11 @@ class System
     /**
      * Sets $_memFree.
      *
-     * @param Integer $memFree free memory
+     * @param int $memFree free memory
      *
      * @see System::$_memFree
      *
-     * @return Void
+     * @return void
      */
     public function setMemFree($memFree)
     {
@@ -1060,7 +1150,7 @@ class System
      *
      * @see System::$_memTotal
      *
-     * @return Integer
+     * @return int
      */
     public function getMemTotal()
     {
@@ -1070,11 +1160,11 @@ class System
     /**
      * Sets $_memTotal.
      *
-     * @param Integer $memTotal total memory
+     * @param int $memTotal total memory
      *
      * @see System::$_memTotal
      *
-     * @return Void
+     * @return void
      */
     public function setMemTotal($memTotal)
     {
@@ -1086,7 +1176,7 @@ class System
      *
      * @see System::$_memUsed
      *
-     * @return Integer
+     * @return int
      */
     public function getMemUsed()
     {
@@ -1096,11 +1186,11 @@ class System
     /**
      * Sets $_memUsed.
      *
-     * @param Integer $memUsed used memory
+     * @param int $memUsed used memory
      *
      * @see System::$_memUsed
      *
-     * @return Void
+     * @return void
      */
     public function setMemUsed($memUsed)
     {
@@ -1127,7 +1217,7 @@ class System
      * @see System::$_swapDevices
      * @see DiskDevice
      *
-     * @return Void
+     * @return void
      */
     public function setSwapDevices($swapDevices)
     {
@@ -1153,7 +1243,7 @@ class System
      *
      * @see System::$_processes
      *
-     * @return Void
+     * @return void
      */
     public function setProcesses($processes)
     {
@@ -1164,4 +1254,64 @@ class System
         }
 */
     }
+
+    /**
+     * Returns $_virtualizer.
+     *
+     * @see System::$_virtualizer
+     *
+     * @return array
+     */
+    public function getVirtualizer()
+    {
+        return $this->_virtualizer;
+    }
+
+    /**
+     * Sets $_virtualizer.
+     *
+     * @param String      $virtualizer virtualizername
+     * @param Bool|String $value       true, false or virtualizername to replace
+     *
+     * @see System::$_virtualizer
+     *
+     * @return void
+     */
+    public function setVirtualizer($virtualizer, $value = true)
+    {
+        if (!isset($this->_virtualizer[$virtualizer])) {
+            if (is_bool($value)) {
+                $this->_virtualizer[$virtualizer] = $value;
+            } else { // replace the virtualizer with another
+                $this->_virtualizer[$virtualizer] = true;
+                $this->_virtualizer[$value] = false;
+            }
+        }
+    }
+
+    /**
+     * Returns $_OS.
+     *
+     * @see System::$_OS
+     *
+     * @return string
+     */
+    public function getOS()
+    {
+        return $this->_OS;
+    }
+
+    /**
+     * Sets $_OS.
+     *
+     * @param $os operating system type
+     *
+     * @see System::$_OS
+     *
+     * @return void
+     */
+    public function setOS($OS)
+    {
+        $this->_OS = $OS;
+    }
 }
