@@ -28,7 +28,7 @@ class SimpleXMLExtended
     /**
      * store the encoding that is used for conversation to utf8
      *
-     * @var String base encoding
+     * @var string base encoding
      */
     private $_encoding = null;
 
@@ -108,7 +108,7 @@ class SimpleXMLExtended
         if ($value == null) {
             return new SimpleXMLExtended($this->_SimpleXmlElement->addChild($nameUtf8), $this->_encoding);
         } else {
-            $valueUtf8 = htmlspecialchars($this->_toUTF8($value));
+            $valueUtf8 = htmlspecialchars($this->_toUTF8($value), ENT_COMPAT, "UTF-8");
 
             return new SimpleXMLExtended($this->_SimpleXmlElement->addChild($nameUtf8, $valueUtf8), $this->_encoding);
         }
@@ -139,12 +139,12 @@ class SimpleXMLExtended
      * @param String $name  name of the attribute
      * @param String $value value of the attribute
      *
-     * @return Void
+     * @return void
      */
     public function addAttribute($name, $value)
     {
         $nameUtf8 = $this->_toUTF8($name);
-        $valueUtf8 = htmlspecialchars($this->_toUTF8($value));
+        $valueUtf8 = htmlspecialchars($this->_toUTF8($value), ENT_COMPAT, "UTF-8");
         if (($valueUtf8 === "") && (version_compare("5.2.2", PHP_VERSION, ">"))) {
             $this->_SimpleXmlElement->addAttribute($nameUtf8, "\0"); // Fixing bug #41175 (addAttribute() fails to add an attribute with an empty value)
         } else {
@@ -157,7 +157,7 @@ class SimpleXMLExtended
      *
      * @param SimpleXMLElement $new_child child that should be appended
      *
-     * @return Void
+     * @return void
      */
     public function combinexml(SimpleXMLElement $new_child)
     {
@@ -176,11 +176,11 @@ class SimpleXMLExtended
      */
     private function _toUTF8($str)
     {
+        $str = trim(preg_replace('/[\x00-\x09\x0b-\x1F]/', ' ', strval($str))); //remove nonprintable characters
         if ($this->_encoding != null) {
             if (strcasecmp($this->_encoding, "UTF-8") == 0) {
-                return trim($str);
+                return $str;
             } elseif (strcasecmp($this->_encoding, "CP437") == 0) {
-                $str = trim($str);
                 $strr = "";
                 if (($strl = strlen($str)) > 0) for ($i = 0; $i < $strl; $i++) {
                     $strc = substr($str, $i, 1);
@@ -197,21 +197,25 @@ class SimpleXMLExtended
                 }
                 $enclist = mb_list_encodings();
                 if (in_array($encoding, $enclist)) {
-                    return mb_convert_encoding(trim($str), 'UTF-8', $encoding);
+                    return mb_convert_encoding($str, 'UTF-8', $encoding);
                 } elseif (function_exists("iconv")) {
-                    if (($iconvout=iconv($encoding, 'UTF-8', trim($str)))!==false) {
+                    if (($iconvout=iconv($encoding, 'UTF-8', $str))!==false) {
                         return $iconvout;
                     } else {
-                        return mb_convert_encoding(trim($str), 'UTF-8');
+                        return mb_convert_encoding($str, 'UTF-8');
                     }
-                } elseif (function_exists("libiconv") && (($iconvout=libiconv($encoding, 'UTF-8', trim($str)))!==false)) {
+                } elseif (function_exists("libiconv") && (($iconvout=libiconv($encoding, 'UTF-8', $str))!==false)) {
                     return $iconvout;
                 } else {
-                    return mb_convert_encoding(trim($str), 'UTF-8');
+                    return mb_convert_encoding($str, 'UTF-8');
                 }
            }
         } else {
-            return mb_convert_encoding(trim($str), 'UTF-8');
+            if (function_exists('mb_convert_encoding')) {
+                return mb_convert_encoding($str, 'UTF-8');
+            } else {
+                return $str;
+            }
         }
     }
 
